@@ -16,17 +16,18 @@ from msldap.commons.url import MSLDAPURLDecoder
 from msldap import logger as msldaplogger
 
 from jackdaw.dbmodel import *
-from jackdaw.gatherer.smb.smb import SMBGathererManager
-from jackdaw.gatherer.ldap.aioldap import LDAPEnumeratorManager
+from jackdaw.gatherer.gatherer import Gatherer
 import json
 import logging
 
 from aiosmb import logger as smblogger
 from msldap import logger as msldaplogger
+import multiprocessing
+from jackdaw.common.cpucount import get_cpu_count
 
 
 class JackdawAutoCollect:
-	def __init__(self, agent_id, agentinfo, db_conn, parallel_cnt = None, progress_queue = None):
+	def __init__(self, agent_id, agentinfo, db_conn, socks_server_info, parallel_cnt = None, progress_queue = None):
 		self.progress_queue = progress_queue
 		self.agentinfo = agentinfo
 		self.agent_id = agent_id
@@ -36,6 +37,7 @@ class JackdawAutoCollect:
 		self.logger = logging.getLogger('jackdawautocollect.process')
 		self.parallel_cnt = parallel_cnt
 		self.domain_server = None
+		self.socks_server_info = socks_server_info
 
 		self.ldapenum = None
 		self.ldapenum_task = None
@@ -56,7 +58,6 @@ class JackdawAutoCollect:
 		if self.smbenum_task is not None:
 			await self.smbenum.terminate()
 			self.smbenum_task.cancel()
-		
 
 	async def gather(self):
 		try:
@@ -65,39 +66,61 @@ class JackdawAutoCollect:
 				'ms' : self.multiplexor_server,
 				'mp' : self.multiplexor_port,
 				'ai' : self.agent_id,
+				'sh' : self.socks_server_info['listen_ip'],
+				'sp' : self.socks_server_info['listen_port']
 			}
-			ldap_url = 'ldap+multiplexor-ntlm://{ds}/?proxytype=multiplexor&proxyhost={ms}&proxyport={mp}&proxyagentid={ai}&authhost={ms}&authport={mp}&authagentid={ai}'.format(**info)
-			smb_url = 'smb+multiplexor-ntlm://{ds}/?proxytype=multiplexor&proxyhost={ms}&proxyport={mp}&proxyagentid={ai}&authhost={ms}&authport={mp}&authagentid={ai}'.format(**info)
+			ldap_url = 'ldap+multiplexor-ntlm://{ds}/?proxytype=socks5&proxyhost={sh}&proxyport={sp}&authhost={ms}&authport={mp}&authagentid={ai}'.format(**info)
+			smb_url = 'smb+multiplexor-ntlm://{ds}/?proxytype=socks5&proxyhost={sh}&proxyport={sp}&authhost={ms}&authport={mp}&authagentid={ai}'.format(**info)
 			self.logger.info(ldap_url)
 			self.logger.info(smb_url)
 			smb_mgr = SMBConnectionURL(smb_url)
 			ldap_mgr = MSLDAPURLDecoder(ldap_url)
 			
-			self.ldapenum = LDAPEnumeratorManager(self.db_conn, ldap_mgr, agent_cnt=self.parallel_cnt, progress_queue=self.progress_queue)
-			self.logger.info('Enumerating LDAP')
-			self.ldapenum_task = asyncio.create_task(self.ldapenum.run())
-			
-			adifo_id = await self.ldapenum_task
-			if adifo_id is None:
-				raise Exception('LDAP enumeration failed!')
-			self.logger.info('ADInfo entry successfully created with ID %s' % adifo_id)
-			
-			self.logger.info('Enumerating SMB')
-			self.smbenum = SMBGathererManager(smb_mgr, worker_cnt=self.parallel_cnt, progress_queue = self.progress_queue)
-			self.smbenum.gathering_type = ['all']
-			self.smbenum.db_conn = self.db_conn
-			self.smbenum.target_ad = adifo_id
-			self.smbenum_task = asyncio.create_task(self.smbenum.run())
+			#self.ldapenum = LDAPEnumeratorManager(self.db_conn, ldap_mgr, agent_cnt=self.parallel_cnt, progress_queue=self.progress_queue)
+			#self.logger.info('Enumerating LDAP')
+			#self.ldapenum_task = asyncio.create_task(self.ldapenum.run())
+			#
+			#adifo_id = await self.ldapenum_task
+			#if adifo_id is None:
+			#	raise Exception('LDAP enumeration failed!')
+			#self.logger.info('ADInfo entry successfully created with ID %s' % adifo_id)
+			#
+			#self.logger.info('Enumerating SMB')
+			#self.smbenum = SMBGathererManager(smb_mgr, worker_cnt=self.parallel_cnt, progress_queue = self.progress_queue)
+			#self.smbenum.gathering_type = ['all']
+			#self.smbenum.db_conn = self.db_conn
+			#self.smbenum.target_ad = adifo_id
+			#self.smbenum_task = asyncio.create_task(self.smbenum.run())
+			#
+			#await self.smbenum_task
 
-			await self.smbenum_task
+			work_dir = './workdir'
 
+			with multiprocessing.Pool() as mp_pool:
+				gatherer = Gatherer(
+					self.db_conn, 
+					work_dir, 
+					ldap_url, 
+					smb_url, 
+					ldap_worker_cnt=None, 
+					smb_worker_cnt=None, 
+					mp_pool=mp_pool, 
+					smb_gather_types=['all'], 
+					progress_queue=self.progress_queue, 
+					show_progress=False,
+					calc_edges=True,
+					dns=None
+				)
+				res, err = await gatherer.run()
+				if err is not None:
+					raise err
 			return True
 		except:
 			logging.exception('Failed to run scan!')
 			return False
 
 	async def run(self):
-		self.domain_server = self.get_domain_server()
+		self.domain_server = self.get_domain_server()		
 		if self.domain_server is None:
 			logging.exception('Failed to get domain server!')
 		
@@ -179,7 +202,9 @@ class MultiplexorAutoStart(MultiplexorOperator):
 			self.agent_tracker[agent_id] = agentinfo
 			self.agent_info_tracker[agentinfo_s] = agent_id
 
-			collect = JackdawAutoCollect(agent_id, agentinfo, db_conn, parallel_cnt=self.parallel_cnt, progress_queue=self.progress_queue)
+			socks_server_info = await self.start_socks5(agent_id)
+
+			collect = JackdawAutoCollect(agent_id, agentinfo, db_conn, socks_server_info, parallel_cnt=self.parallel_cnt, progress_queue=self.progress_queue)
 			await collect.run()
 
 			shutil.move(str(db_file_path), str(self.sqlite_finished_folder))
@@ -237,9 +262,9 @@ def main():
 	parser = argparse.ArgumentParser(description='auto collector for MP')
 	#parser.add_argument('-v', '--verbose', action='count', default=0, help='Increase verbosity, can be stacked')
 	#parser.add_argument('sql', help='SQL connection string in URL format')
-	parser.add_argument('sqlite_folder_path', help='A folder to store enumeration results in')
+	parser.add_argument('-q', '--sqlite_folder_path', default='./workdir', help='A folder to store enumeration results in')
 	parser.add_argument('-m', '--multiplexor', default = 'ws://127.0.0.1:9999', help='multiplexor connection string in URL format')
-	parser.add_argument('-p', '--parallel_cnt', default = len(os.sched_getaffinity(0)), type=int, help='agent count')
+	parser.add_argument('-p', '--parallel_cnt', default = get_cpu_count(), type=int, help='agent count')
 	parser.add_argument('-o', '--progress-out-file', default = None, help='Filename to write progress to')
 	parser.add_argument('-s', '--start-ui', action='store_true', help='Automatically start jackdaw UI after successful enumeration')
 
@@ -252,6 +277,7 @@ def main():
 	logging.getLogger('websockets.client').setLevel(logging.ERROR)
 	logging.getLogger('websockets.protocol').setLevel(logging.ERROR)
 	logging.getLogger('aiosmb').setLevel(100)
+	logging.getLogger('asysocks').setLevel(100)
 
 	
 	mas = MultiplexorAutoStart(args.multiplexor, args.sqlite_folder_path, parallel_cnt=args.parallel_cnt, progress_file_name = args.progress_out_file, start_ui = args.start_ui)
